EOF
===

.. currentmodule:: xeofs.single

.. autoclass:: EOF
   :members:
   :inherited-members:

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~EOF.__init__
      ~EOF.components
      ~EOF.compute
      ~EOF.deserialize
      ~EOF.explained_variance
      ~EOF.explained_variance_ratio
      ~EOF.fit
      ~EOF.fit_transform
      ~EOF.get_params
      ~EOF.get_serialization_attrs
      ~EOF.inverse_transform
      ~EOF.load
      ~EOF.save
      ~EOF.scores
      ~EOF.serialize
      ~EOF.singular_values
      ~EOF.transform
   
   

   
   
   